#!/bin/bash
#
# - Called from xinetd/cdeadmin service
# - Executes /etc/cdeadmin/web_scripts/starterkit
# 

tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/test$$
trap "rm -f $tempfile" 0 1 2 5 15

logfile="/var/log/secfs.log";

source /etc/secfs/secfs.cfg
if [ -f /etc/secfs/custom_config.cfg ]
	then
	source /etc/secfs/custom_config.cfg
fi

# Start of Main
# ------------

read action param1 param2 param3

# SECFS
# ----------
# Rebuild smb.conf
if [ "$action" = "samba_rebuild" ]
	then
	exec /bin/secfs_config 
	exit;
fi


# USERS
# --------------

# Create user
# param1 = username, param2 = password
if [ "$action" = "create_user" ]
	then
	exec /bin/secfs_admin -newuser "$param1" "$param2"
	exit;
fi

#Modify
# param1 = username, param2 = newstatus (activate,lock)
if [ "$action" = "modify_user" ]
	then
	exec /bin/secfs_admin -modify_user "$param1" "$param2"
	exit;
fi

#delete user
# param1 = username, param2 = datadir (yes=delete)
if [ "$action" = "delete_user" ]
	then
	exec /bin/secfs_admin -deluser "$param1" "$param2"
	exit;
fi
# change password
# param1 = username, param2 = password
if [ "$action" = "change_password" ]
	then
	exec /bin/secfs_admin -change_password "$param1" "$param2"
	exit;
fi

# SHARE FOLDERS
# ---------------
if [ "$action"  = "create_folder" ] 
	then
	exec /bin/secfs_admin -create_folder "$param1" "$param2"
	exit;
fi

#param1 = folder_id, param2=sharename (/home/<name>) , param3= folderdat (yes=delete)
if [ "$action"  = "delete_folder" ] 
	then
	exec /bin/secfs_admin -delete_folder "$param1" "$param2" "$param3"
	exit;
fi

echo "SRV_ERROR";

exit 0;

